%--------------------------------------------------------------------------
%                    RAWSEEDS VISUALIZATION TOOLKIT
%                       http://www.rawseeds.org/
%--------------------------------------------------------------------------
%   experiment_viewer.m
%
%   This script shows the experiment from the selected RAWSEEDS dataset.
% 
%   For more information, refer to the project site: www.rawseeds.org
%
%   Authors: C. Cadena & J. Neira, University of Zaragoza, Spain
%--------------------------------------------------------------------------
%   Version: 1.0    20-nov-2009
%--------------------------------------------------------------------------
%   History:
%--------------------------------------------------------------------------

close all;
clear all;

global PARAMETERS timestamps DATA

PARAMETERS.DataPath      = '../datasets'; % where the datasets are?
  
% PARAMETERS.DatasetName   = 'Bicocca_2009-02-25a';  % Indoor
PARAMETERS.DatasetName   = 'Bicocca_2009-02-25b';  % Indoor
% PARAMETERS.DatasetName   = 'Bicocca_2009-02-26a';  % Indoor
% PARAMETERS.DatasetName   = 'Bicocca_2009-02-26b';  % Indoor
% PARAMETERS.DatasetName   = 'Bicocca_2009-02-27a';  % Indoor
% PARAMETERS.DatasetName   = 'Bovisa_2008-09-01_Static';   % Mixed
% PARAMETERS.DatasetName   = 'Bovisa_2008-10-06_Dynamic';  % Mixed
% PARAMETERS.DatasetName   = 'Bovisa_2008-10-11a_Static';  % Mixed
% PARAMETERS.DatasetName   = 'Bovisa_2008-10-04_Static';   % Outdoor
% PARAMETERS.DatasetName   = 'Bovisa_2008-10-07_Dynamic';  % Outdoor
% PARAMETERS.DatasetName   = 'Bovisa_2008-10-11b_Static';  % Outdoor

% activate sensors
PARAMETERS.Sensors.SVS_T        = 1;
PARAMETERS.Sensors.SVS_L        = 1;
PARAMETERS.Sensors.SVS_R        = 1;
PARAMETERS.Sensors.FRONTAL      = 1;
PARAMETERS.Sensors.OMNI         = 1;
PARAMETERS.Sensors.SICK_FRONT   = 1;
PARAMETERS.Sensors.SICK_REAR    = 1;
PARAMETERS.Sensors.HOKUYO_FRONT = 1;
PARAMETERS.Sensors.HOKUYO_REAR  = 1;
PARAMETERS.Sensors.ODOMETRY     = 1;
PARAMETERS.Sensors.IMU          = 1;
PARAMETERS.Sensors.GPS          = 0; % only for Bovisa
PARAMETERS.Sensors.GT_EXTENDED  = 1; % only for Bicocca 


%% import sensor
folder=[PARAMETERS.DataPath,'/',PARAMETERS.DatasetName,'/'];
dataset=PARAMETERS.DatasetName;
ind_=find(dataset=='_',1,'last');
if ind_>9, dataset=dataset(1:ind_-1); end

PARAMETERS.dataset=dataset;
PARAMETERS.folder=folder;

disp('--------------------------------------------------------------------');
disp('                 RAWSEEDS VISUALIZATION TOOLKIT                     ');
disp('--------------------------------------------------------------------');

tstart=inf;
tfinal=0;

if PARAMETERS.Sensors.SVS_T
    tT_file=[dataset,'-LISTS/',dataset,'-SVS_T.csv'];
    fprintf('Loading SVS_T file:        %s\n',tT_file);
    if exist([folder,tT_file],'file')
        timestamps.tT=importdata([folder,tT_file]);
        tstart=min(tstart,timestamps.tT(1));
        tfinal=max(tfinal,timestamps.tT(end));
    else
        fprintf('  Warning:   File not found\n');
    end
end
if PARAMETERS.Sensors.SVS_L
    tL_file=[dataset,'-LISTS/',dataset,'-SVS_L.csv'];
    fprintf('Loading SVS_L file:        %s\n',tL_file);
    if exist([folder,tL_file],'file')
        timestamps.tL=importdata([folder,tL_file]);
        tstart=min(tstart,timestamps.tL(1));
        tfinal=max(tfinal,timestamps.tL(end));
    else
        fprintf('  Warning:   File not found\n');
    end
end
if PARAMETERS.Sensors.SVS_R
    tR_file=[dataset,'-LISTS/',dataset,'-SVS_R.csv'];
    fprintf('Loading SVS_R file:        %s\n',tR_file);
    if exist([folder,tR_file],'file')
        timestamps.tR=importdata([folder,tR_file]);
        tstart=min(tstart,timestamps.tR(1));
        tfinal=max(tfinal,timestamps.tR(end));
    else
        fprintf('  Warning:   File not found\n');
    end
end
if PARAMETERS.Sensors.FRONTAL
    tF_file=[dataset,'-LISTS/',dataset,'-FRONTAL.csv'];
    fprintf('Loading FRONTAL file:      %s\n',tF_file);
    if exist([folder,tF_file],'file')
        timestamps.tF=importdata([folder,tF_file]);
        tstart=min(tstart,timestamps.tF(1));
        tfinal=max(tfinal,timestamps.tF(end));
    else
        fprintf('  Warning:   File not found\n');
    end
end
if PARAMETERS.Sensors.OMNI
    tO_file=[dataset,'-LISTS/',dataset,'-OMNI.csv'];
    fprintf('Loading OMNI file:         %s\n',tO_file);
    if exist([folder,tO_file],'file')
        timestamps.tO=importdata([folder,tO_file]);
        tstart=min(tstart,timestamps.tO(1));
        tfinal=max(tfinal,timestamps.tO(end));
    else
        fprintf('  Warning:   File not found\n');
    end
end
if PARAMETERS.Sensors.SICK_FRONT
    SF_file=[dataset,'-SICK_FRONT.csv'];
    fprintf('Loading SICK_FRONT file:   %s\n',SF_file);
    if exist([folder,SF_file],'file')
        DATA.SF = importdata([folder,SF_file]);
        timestamps.SF=DATA.SF(:,1);
        tstart=min(tstart,timestamps.SF(1));
        tfinal=max(tfinal,timestamps.SF(end));
    else
        fprintf('  Warning:   File not found\n');
    end
end
if PARAMETERS.Sensors.SICK_REAR
    SR_file=[dataset,'-SICK_REAR.csv'];
    fprintf('Loading SICK_REAR file:    %s\n',SR_file);
    if exist([folder,SR_file],'file')
        DATA.SR = importdata([folder,SR_file]);
        timestamps.SR=DATA.SR(:,1);
        tstart=min(tstart,timestamps.SR(1));
        tfinal=max(tfinal,timestamps.SR(end));
    else
        fprintf('  Warning:   File not found\n');
    end
end
if PARAMETERS.Sensors.HOKUYO_FRONT
    HF_file=[dataset,'-HOKUYO_FRONT.csv'];
    fprintf('Loading HOKUYO_FRONT file: %s\n',HF_file);
    if exist([folder,HF_file],'file')
        DATA.HF = importdata([folder,HF_file]);
        timestamps.HF=DATA.HF(:,1);
        tstart=min(tstart,timestamps.HF(1));
        tfinal=max(tfinal,timestamps.HF(end));
    else
        fprintf('  Warning:   File not found\n');
    end
end
if PARAMETERS.Sensors.HOKUYO_REAR
    HR_file=[dataset,'-HOKUYO_REAR.csv'];
    fprintf('Loading HOKUYO_REAR file:  %s\n',HR_file);
    if exist([folder,HR_file],'file')
        DATA.HR = importdata([folder,HR_file]);
        timestamps.HR=DATA.HR(:,1);
        tstart=min(tstart,timestamps.HR(1));
        tfinal=max(tfinal,timestamps.HR(end));
    else
        fprintf('  Warning:   File not found\n');
    end
end
if PARAMETERS.Sensors.ODOMETRY
    OD_file=[dataset,'-ODOMETRY_XYT.csv'];
    fprintf('Loading ODOMETRY file:     %s\n',OD_file);
    if exist([folder,OD_file],'file')
        DATA.odometry = importdata([folder,OD_file]);
        timestamps.OD=DATA.odometry(:,1);
        tstart=min(tstart,timestamps.OD(1));
        tfinal=max(tfinal,timestamps.OD(end));
    else
        fprintf('  Warning:   File not found\n');
    end
end
if PARAMETERS.Sensors.IMU
    IMU_file=[dataset,'-IMU_STRETCHED.csv'];
    fprintf('Loading IMU file:          %s\n',IMU_file);
    if exist([folder,IMU_file],'file')
        DATA.IMU=importdata([folder,IMU_file]);
        timestamps.IMU=DATA.IMU(:,1);
        tstart=min(tstart,timestamps.IMU(1));
        tfinal=max(tfinal,timestamps.IMU(end));
    else
        fprintf('  Warning:   File not found\n');
    end
end
if PARAMETERS.Sensors.GPS
    GT_file=[dataset,'-GPS.csv'];
    fprintf('Loading GT file:           %s\n',GT_file);
    if exist([folder,GT_file],'file')
        DATA.GT=read_gps([folder,GT_file],[0,inf],0.8);
        timestamps.GT=DATA.GT(:,1);
        tstart=min(tstart,timestamps.GT(1));
        tfinal=max(tfinal,timestamps.GT(end));
    else
        fprintf('  Warning:   File not found\n');
    end
end
if PARAMETERS.Sensors.GT_EXTENDED
    GT_file=[dataset,'-GT-extended.csv'];
    fprintf('Loading GT file:           %s\n',GT_file);
    if exist([folder,GT_file],'file')
        DATA.GT = importdata([folder,GT_file]);
        timestamps.GT=DATA.GT(:,1);
        tstart=min(tstart,timestamps.GT(1));
        tfinal=max(tfinal,timestamps.GT(end));
    else
        fprintf('  Warning:   File not found\n');
    end
end

timestamps.start=tstart;
timestamps.final=tfinal;
timestamps.current=timestamps.start;

if ~isinf(tstart) && ~isnan(tstart) && tfinal>0 && ~isnan(tfinal)
    experiment;
end