%--------------------------------------------------------------------------
%                    RAWSEEDS VISUALIZATION TOOLKIT
%                       http://www.rawseeds.org/
%--------------------------------------------------------------------------
%   imu_viewer.m
%
%   This script loads IMU files from the selected RAWSEEDS dataset for
%   visualize the laser data. 
% 
%   For more information, refer to the project site: www.rawseeds.org
%
%   Authors: C. Cadena & J. Neira, University of Zaragoza, Spain
%--------------------------------------------------------------------------
%   Version: 1.0    20-nov-2009
%--------------------------------------------------------------------------
%   History:
%--------------------------------------------------------------------------

close all
clear all

global PARAMETERS

PARAMETERS.DataPath      = '../datasets';
  
% PARAMETERS.DatasetName   = 'Bicocca_2009-02-25a';  % Indoor
PARAMETERS.DatasetName   = 'Bicocca_2009-02-25b';  % Indoor
% PARAMETERS.DatasetName   = 'Bicocca_2009-02-26a';  % Indoor
% PARAMETERS.DatasetName   = 'Bicocca_2009-02-26b';  % Indoor
% PARAMETERS.DatasetName   = 'Bicocca_2009-02-27a';  % Indoor
% PARAMETERS.DatasetName   = 'Bovisa_2008-09-01_Static';   % Mixed
% PARAMETERS.DatasetName   = 'Bovisa_2008-10-06_Dynamic';  % Mixed
% PARAMETERS.DatasetName   = 'Bovisa_2008-10-11a_Static';  % Mixed
% PARAMETERS.DatasetName   = 'Bovisa_2008-10-04_Static';   % Outdoor
% PARAMETERS.DatasetName   = 'Bovisa_2008-10-07_Dynamic';  % Outdoor
% PARAMETERS.DatasetName   = 'Bovisa_2008-10-11b_Static';  % Outdoor

PARAMETERS.imu       = '-IMU_STRETCHED.csv'; 

PARAMETERS.increments = 1;

%% import files

folder=[PARAMETERS.DataPath,'/',PARAMETERS.DatasetName,'/'];
dataset=PARAMETERS.DatasetName;

disp('--------------------------------------------------------------------');
disp('                  RAWSEEDS BENCHMARKING TOOLKIT                     ');
disp('--------------------------------------------------------------------');

ind_=find(dataset=='_',1,'last');
if ind_>9, dataset=dataset(1:ind_-1); end

file_imu=[dataset,PARAMETERS.imu];
fprintf('Loading IMU file:  %s \n',[folder,file_imu]);
imu = importdata([folder,file_imu]);

%% draw

disp('--------------------------------------------------------------------');
disp('                          Viewing: IMU'                              );
disp('--------------------------------------------------------------------');

timestamps = imu(:,1);
steps=size(imu,1);
first = 1;
inc=PARAMETERS.increments;

figure;
hf=gcf;
set(hf,'name','RAWSEEDS VISUALIZATION TOOLKIT',...
    'Position',[250 250 800 400],'NumberTitle','off');

subplot(1,2,1)
hz=quiver3(0,0,9.8,0,0,0); set(hz,'LineWidth',10,'Color',[1,0.7,0.7]); hold on
hx=quiver3(0,0,9.8,0,0,0); set(hx,'LineWidth',10,'Color',[0.7,0.7,1]);
hy=quiver3(0,0,9.8,0,0,0); set(hy,'LineWidth',10,'Color',[0.7,1,0]);

haa=gca;
set(haa,'Color',[0.8 0.8 0.8]);
axis equal
axis([-1 1 -1 1 9.5 11]);
text(0.5,-0.1,9.8,'X');
text(0,0.5,9.9,'Y');
text(0,-0.1,10.3,'Z');
hax=quiver3(0,0,9.8,1,0,0); set(hax,'LineWidth',1,'Color',[0,0,1],'MaxHeadSize',1);
hay=quiver3(0,0,9.8,0,1,0); set(hay,'LineWidth',1,'Color',[0,1,0],'MaxHeadSize',1);
haz=quiver3(0,0,9.8,0,0,1); set(haz,'LineWidth',1,'Color',[1,0,0],'MaxHeadSize',1);

title('Linear Accleration (m/s^2)');

subplot(1,2,2)
hwz=bar([1,2,3],[0,0,0]); set(hwz,'FaceColor',[1,0.7,0.7],'EdgeColor',[1,0.7,0.7]); 
hold on
hwy=bar([1,2,3],[0,0,0]); set(hwy,'FaceColor',[0.7,1,0.7],'EdgeColor',[0.7,1,0.7]);
hwx=bar([1,2,3],[0,0,0]); set(hwx,'FaceColor',[0.7,0.7,1],'EdgeColor',[0.7,0.7,1]); 

haw=gca;
axis([0.5 3.5 -0.8 0.8]);
set(haw,'Color',[0.8 0.8 0.8],'XTickLabel',['X';'Y';'Z'],...
    'Position',[0.6 0.2 0.37 0.6]);
title('Angular Velocity (rad/s)');

ht= uicontrol('Style','Text','Position',[312,362,220,20],...
    'string',['Timestamp: ',num2str(timestamps(first),'%3.4f'),' s'],...
    'BackgroundColor',[0.8 0.8 0.8],'FontSize',10);

for i = first+inc:inc:steps
    set(hx,'UData',imu(i,3));
    set(hy,'VData',imu(i,4));
    set(hz,'WData',imu(i,5)-9.8);
    set(ht,'string',['Timestamp: ',num2str(timestamps(i),'%3.4f'),' s']);
    set(hwx,'YData',[imu(i,6),0,0]);
    set(hwy,'YData',[0,imu(i,7),0]);
    set(hwz,'YData',[0,0,imu(i,8)]);
    drawnow
end