function laser_viewer

%--------------------------------------------------------------------------
%                    RAWSEEDS VISUALIZATION TOOLKIT
%                       http://www.rawseeds.org/
%--------------------------------------------------------------------------
%   function laser_viewer()
%
%   This function loads laser files from the selected RAWSEEDS dataset for
%   visualize the laser data.
% 
%   For more information, refer to the project site: www.rawseeds.org
%
%   Authors: C. Cadena & J. Neira, University of Zaragoza, Spain
%--------------------------------------------------------------------------
%   Version: 1.0    20-nov-2009
%--------------------------------------------------------------------------
%   History:
%--------------------------------------------------------------------------

close all
clear all

global PARAMETERS

PARAMETERS.laser_front   = 1;  %1 front, 0 rear
PARAMETERS.laser_sick    = 1;  %1 SICK, 0 HOKUYO

PARAMETERS.DataPath      = '../datasets'; % where the datasets are? 
  
% PARAMETERS.DatasetName   = 'Bicocca_2009-02-25a';  % Indoor
  PARAMETERS.DatasetName   = 'Bicocca_2009-02-25b';  % Indoor
% PARAMETERS.DatasetName   = 'Bicocca_2009-02-26a';  % Indoor
% PARAMETERS.DatasetName   = 'Bicocca_2009-02-26b';  % Indoor
% PARAMETERS.DatasetName   = 'Bicocca_2009-02-27a';  % Indoor
% PARAMETERS.DatasetName   = 'Bovisa_2008-09-01_Static';   % Mixed
% PARAMETERS.DatasetName   = 'Bovisa_2008-10-06_Dynamic';  % Mixed
% PARAMETERS.DatasetName   = 'Bovisa_2008-10-11a_Static';  % Mixed
% PARAMETERS.DatasetName   = 'Bovisa_2008-10-04_Static';   % Outdoor
% PARAMETERS.DatasetName   = 'Bovisa_2008-10-07_Dynamic';  % Outdoor
% PARAMETERS.DatasetName   = 'Bovisa_2008-10-11b_Static';  % Outdoor

PARAMETERS.increments = 1;

%% import sensor
folder=[PARAMETERS.DataPath,'/',PARAMETERS.DatasetName,'/'];
dataset=PARAMETERS.DatasetName;
ind_=find(dataset=='_',1,'last');
if ind_>9, dataset=dataset(1:ind_-1); end

disp('--------------------------------------------------------------------');
disp('                 RAWSEEDS VISUALIZATION TOOLKIT                     ');
disp('--------------------------------------------------------------------');

laser_file=dataset;
if PARAMETERS.laser_sick
    laser_file=[laser_file,'-SICK'];
else
    laser_file=[laser_file,'-HOKUYO'];
end
if PARAMETERS.laser_front
    laser_file=[laser_file,'_FRONT.csv'];
else
    laser_file=[laser_file,'_REAR.csv'];
end

data=importdata([folder,laser_file]);

%% draw
steps = size(data,1);

if PARAMETERS.laser_sick
    maxdist = 80;  % max range in meters
    angles = (-90 : 1 : 90) *pi/180; % field of view in radians
    ind_data= 4;
    name='SICK';
else
    maxdist = 5.6; % max range in meters
    angles = (-120 : 360/1024 : 120) *pi/180; % field of view in radians
    ind_data= 2;
    name='HOKUYO';
end
max_axis=[-3 maxdist*1.1 -maxdist*1.1 maxdist*1.1];

if ~PARAMETERS.laser_front
    angles=angles+pi;
    max_axis=[-maxdist*1.1 3 -maxdist*1.1 maxdist*1.1];
    name=[name,' REAR'];
else
    name=[name,' FRONT'];
end
disp('--------------------------------------------------------------------');
disp(['                       Viewing: ',name]);
disp('--------------------------------------------------------------------');

timestamps = data(:,1);
scans = data(:,ind_data:end);

first = 1;
inc=PARAMETERS.increments;
Q = scan2cart(scans(first,:),maxdist,angles);   %Cartesian coordinates in meters

figure;
hf=gcf;
set(hf,'name','RAWSEEDS VISUALIZATION TOOLKIT','position',[500 50 400 640],...
    'NumberTitle','off');
h=plot(Q(1,:), Q(2,:), 'b.'); 
hp=patch(Q(1,:)', Q(2,:)', 'w'); 
ha=gca;
set(ha,'color',[0.8 0.8 0.8]);
axis equal;
axis(max_axis);
ht=title(['Timestamp: ',num2str(timestamps(first),'%3.4f'),' s']);
legend(name);

for i = first+inc:inc:steps
    Q = scan2cart(scans(i,:),maxdist,angles);  
    set(h,'XData',Q(1,:),'YData',Q(2,:));
    set(hp,'XData',Q(1,:)','YData',Q(2,:)');
    set(ht,'string',['Timestamp: ',num2str(timestamps(i),'%3.4f'),' s']);
    drawnow
end

function Q = scan2cart(scan,maxdist,angles)

valid = find(scan < maxdist);
[x,y] = pol2cart(angles(valid), scan(valid));
Q=[x;y];
